==> storageproviderdata-4.0.1-sources.jar: org/duracloud/s3storageprovider/dto/GetUrlTaskResult.java <==
/*
 * The contents of this file are subject to the license and copyright
 * detailed in the LICENSE and NOTICE files at the root of the source
 * tree and available online at
 *
 *     http://duracloud.org/license/
 */
package org.duracloud.s3storageprovider.dto;

import org.duracloud.common.json.JaxbJsonSerializer;
import org.duracloud.error.TaskDataException;

import javax.xml.bind.annotation.XmlValue;
import java.io.IOException;

/**
 * @author Bill Branan
 *         Date: 3/23/15
 */
public class GetUrlTaskResult {

    /**
     * The securely signed streaming URL
     */
    @XmlValue
    private String streamUrl;

    // Required by JAXB
    public GetUrlTaskResult() {}

    public GetUrlTaskResult(String signedUrl) {
        this.streamUrl = streamUrl;
    }

    public String getStreamUrl() {
        return streamUrl;
    }

    public void setStreamUrl(String streamUrl) {
        this.streamUrl = streamUrl;
    }

    /**
     * Creates a serialized version of task results
     *
     * @return JSON formatted task result info
     */
    public String serialize() {
        JaxbJsonSerializer<GetUrlTaskResult> serializer =
            new JaxbJsonSerializer<>(GetUrlTaskResult.class);
        try {
            return serializer.serialize(this);
        } catch(IOException e) {
            throw new TaskDataException(
                "Unable to create task result due to: " + e.getMessage());
        }
    }

    /**
     * Parses properties from task result
     *
     * @param taskResult - JSON formatted set of properties
     */
    public static GetUrlTaskResult deserialize(String taskResult) {
        JaxbJsonSerializer<GetUrlTaskResult> serializer =
            new JaxbJsonSerializer<>(GetUrlTaskResult.class);
        try {
            return serializer.deserialize(taskResult);
        } catch(IOException e) {
            throw new TaskDataException(
                "Unable to create task result due to: " + e.getMessage());
        }
    }
    
}

==> storageproviderdata-8.0.0-sources.jar: org/duracloud/s3storageprovider/dto/GetUrlTaskResult.java <==
/*
 * The contents of this file are subject to the license and copyright
 * detailed in the LICENSE and NOTICE files at the root of the source
 * tree and available online at
 *
 *     http://duracloud.org/license/
 */
package org.duracloud.s3storageprovider.dto;

import java.io.IOException;
import javax.xml.bind.annotation.XmlValue;

import org.duracloud.common.json.JaxbJsonSerializer;
import org.duracloud.error.TaskDataException;

/**
 * @author Bill Branan
 * Date: 3/23/15
 */
public class GetUrlTaskResult {

    /**
     * The securely signed streaming URL
     */
    @XmlValue
    private String streamUrl;

    // Required by JAXB
    public GetUrlTaskResult() {
    }

    public GetUrlTaskResult(String signedUrl) {
        this.streamUrl = streamUrl;
    }

    public String getStreamUrl() {
        return streamUrl;
    }

    public void setStreamUrl(String streamUrl) {
        this.streamUrl = streamUrl;
    }

    /**
     * Creates a serialized version of task results
     *
     * @return JSON formatted task result info
     */
    public String serialize() {
        JaxbJsonSerializer<GetUrlTaskResult> serializer =
            new JaxbJsonSerializer<>(GetUrlTaskResult.class);
        try {
            return serializer.serialize(this);
        } catch (IOException e) {
            throw new TaskDataException(
                "Unable to create task result due to: " + e.getMessage());
        }
    }

    /**
     * Parses properties from task result
     *
     * @param taskResult - JSON formatted set of properties
     */
    public static GetUrlTaskResult deserialize(String taskResult) {
        JaxbJsonSerializer<GetUrlTaskResult> serializer =
            new JaxbJsonSerializer<>(GetUrlTaskResult.class);
        try {
            return serializer.deserialize(taskResult);
        } catch (IOException e) {
            throw new TaskDataException(
                "Unable to create task result due to: " + e.getMessage());
        }
    }

}
